@@ -40,6 +40,14 @@ docs_files = ["README", "copying", "NEWS", "TODO", "INSTALL",]
 
 data_files = [
   ('/usr/share/applications/hildon', desktop_file),
+  ('/usr/share/icons/hicolor/scalable/hildon',['data/icons/64x64/scribo.png']),
+  ('/usr/share/icons/hicolor/26x26/hildon',['data/icons/26x26/scribo.png']),
+  ('/usr/share/icons/hicolor/40x40/hildon',['data/icons/40x40/scribo.png']),
+  ('/usr/share/icons/hicolor/64x64/hildon',['data/icons/64x64/scribo.png']),
+  ('/usr/share/icons/hicolor/26x26/apps',['data/icons/26x26/scribo.png']),
+  ('/usr/share/icons/hicolor/40x40/apps',['data/icons/40x40/scribo.png']),
+  ('/usr/share/icons/hicolor/64x64/apps',['data/icons/64x64/scribo.png']),
+  ('/usr/share/pixmap',['data/icons/pixmap/scribo.xpm']),
   ('/opt/scribo/src', srcs),
   ('/opt/scribo/src/ui', uisrcs),
   ('/opt/scribo/src/bug', bugsrcs),
