@@ -13,6 +13,7 @@ __copyright__ = ""
 __license__ = "GPLv2"
 
 import sys
+import os
 # import python dbus module
 #import dbus
 # import python dbus GLib mainloop support
@@ -51,7 +52,10 @@ def main():
         #translator.load("scribo_ru.qm")
         #app.installTranslator(translator)
         import locale, os
-        mylocale = locale.getdefaultlocale()[0]
+        try:
+            mylocale = locale.getdefaultlocale()[0]
+        except ValueError:
+            mylocale = None
         if mylocale == None:
             pass
         else:
@@ -79,5 +83,5 @@ def main():
 
 
 if __name__ == "__main__":
-
+    os.chdir(os.path.dirname(os.path.abspath(sys.argv[0])))
     main()
