@@ -43,7 +43,7 @@
         <translation type="obsolete">Отправка</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="423"/>
+        <location filename="AddPost.py" line="433"/>
         <source>Scribo</source>
         <translation type="unfinished">Scribo</translation>
     </message>
@@ -63,7 +63,7 @@
         <translation type="obsolete">Пост изменен</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="237"/>
+        <location filename="AddPost.py" line="247"/>
         <source>Add picture</source>
         <translation type="unfinished">Добавить рисунок</translation>
     </message>
@@ -73,12 +73,12 @@
         <translation type="obsolete">Добавить ссылку на рисунок</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="405"/>
+        <location filename="AddPost.py" line="415"/>
         <source>Add</source>
         <translation type="unfinished">Добавить</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="266"/>
+        <location filename="AddPost.py" line="276"/>
         <source>Add link</source>
         <translation type="unfinished">Добавить ссылку</translation>
     </message>
@@ -93,52 +93,52 @@
         <translation type="obsolete">Добавить html теги</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="307"/>
+        <location filename="AddPost.py" line="317"/>
         <source>Bold</source>
         <translation type="unfinished">Жирный</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="309"/>
+        <location filename="AddPost.py" line="319"/>
         <source>Italic</source>
         <translation type="unfinished">Курсив</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="311"/>
+        <location filename="AddPost.py" line="321"/>
         <source>Center</source>
         <translation type="unfinished">По центру</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="313"/>
+        <location filename="AddPost.py" line="323"/>
         <source>Right</source>
         <translation type="unfinished">По правому краю</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="315"/>
+        <location filename="AddPost.py" line="325"/>
         <source>Left</source>
         <translation type="unfinished">По левому краю</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="317"/>
+        <location filename="AddPost.py" line="327"/>
         <source>Justify</source>
         <translation type="unfinished">По ширине</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="319"/>
+        <location filename="AddPost.py" line="329"/>
         <source>Color</source>
         <translation type="unfinished">Цвет</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="361"/>
+        <location filename="AddPost.py" line="371"/>
         <source>Color text</source>
         <translation type="unfinished">Цветной текст</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="364"/>
+        <location filename="AddPost.py" line="374"/>
         <source>Choose color</source>
         <translation type="unfinished">Выбрать цвет</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="392"/>
+        <location filename="AddPost.py" line="402"/>
         <source>Add option</source>
         <translation type="unfinished">Добавить опцию</translation>
     </message>
@@ -168,12 +168,12 @@
         <translation type="obsolete">Вы хотите отправить пост с пустым заголовком?</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="221"/>
+        <location filename="AddPost.py" line="231"/>
         <source>Post is edit</source>
         <translation type="unfinished">Пост редактирован</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="304"/>
+        <location filename="AddPost.py" line="314"/>
         <source>Add html tags</source>
         <translation type="unfinished">Добавить html теги</translation>
     </message>
@@ -188,57 +188,57 @@
         <translation type="unfinished">../data/en/image.png</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="122"/>
+        <location filename="AddPost.py" line="123"/>
         <source>../data/en/add_link.png</source>
         <translation type="unfinished">../data/en/add_link.png</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="128"/>
+        <location filename="AddPost.py" line="131"/>
         <source>../data/en/add_html.png</source>
         <translation type="unfinished">../data/en/add_html.png</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="134"/>
+        <location filename="AddPost.py" line="139"/>
         <source>../data/en/options.png</source>
         <translation type="unfinished">../data/en/options.png</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="144"/>
+        <location filename="AddPost.py" line="151"/>
         <source>../data/en/post_send_to.png</source>
         <translation type="unfinished">../data/en/post_send_to.png</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="149"/>
+        <location filename="AddPost.py" line="156"/>
         <source>../data/en/send_post.png</source>
         <translation type="unfinished">../data/en/send_post.png</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="194"/>
+        <location filename="AddPost.py" line="204"/>
         <source>The post is empty!</source>
         <translation type="unfinished">Пост - пустой!!</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="201"/>
+        <location filename="AddPost.py" line="211"/>
         <source>Do you want to send post with empty subject?</source>
         <translation type="unfinished">Вы действительно хотите послать пост без темы?</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="238"/>
+        <location filename="AddPost.py" line="248"/>
         <source>Link to the image (URL)</source>
         <translation type="unfinished">Ссылка на изображение(URL)</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="270"/>
+        <location filename="AddPost.py" line="280"/>
         <source>Link</source>
         <translation type="unfinished">Ссылка</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="402"/>
+        <location filename="AddPost.py" line="412"/>
         <source>Tags (comma separated)</source>
         <translation type="unfinished">Теги (через запятую)</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="425"/>
+        <location filename="AddPost.py" line="435"/>
         <source>Post will be lost! Continue? </source>
         <translation type="unfinished">Пост будет утерян! Продолжить?</translation>
     </message>
@@ -248,22 +248,22 @@
         <translation type="unfinished">Изображение</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="127"/>
+        <location filename="AddPost.py" line="132"/>
         <source>HTML</source>
         <translation type="unfinished">HTML</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="133"/>
+        <location filename="AddPost.py" line="140"/>
         <source>Options</source>
         <translation type="unfinished">Опции</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="143"/>
+        <location filename="AddPost.py" line="152"/>
         <source>Send to..</source>
         <translation type="unfinished">Отправить в ..</translation>
     </message>
     <message>
-        <location filename="AddPost.py" line="148"/>
+        <location filename="AddPost.py" line="157"/>
         <source>Send</source>
         <translation type="unfinished">Отправить</translation>
     </message>
@@ -296,12 +296,12 @@
         <translation type="obsolete">Да</translation>
     </message>
     <message>
-        <location filename="AddProfile.py" line="239"/>
+        <location filename="AddProfile.py" line="243"/>
         <source>Scribo</source>
         <translation type="unfinished">Scribo</translation>
     </message>
     <message>
-        <location filename="AddProfile.py" line="180"/>
+        <location filename="AddProfile.py" line="184"/>
         <source>Please, fill all fields!</source>
         <translation type="unfinished">Пожалуйста, заполните все поля!</translation>
     </message>
@@ -311,12 +311,12 @@
         <translation type="obsolete">Вы действительно хотите удалить аккаунт?</translation>
     </message>
     <message>
-        <location filename="AddProfile.py" line="240"/>
+        <location filename="AddProfile.py" line="244"/>
         <source>Account was deleted</source>
         <translation type="unfinished">Аккаунт удален</translation>
     </message>
     <message>
-        <location filename="AddProfile.py" line="225"/>
+        <location filename="AddProfile.py" line="229"/>
         <source>Do you really want to delete account?</source>
         <translation type="unfinished">Вы действительно хотите удалить аккаунт?</translation>
     </message>
@@ -326,32 +326,32 @@
         <translation type="unfinished">Блог сервис</translation>
     </message>
     <message>
-        <location filename="AddProfile.py" line="110"/>
+        <location filename="AddProfile.py" line="109"/>
         <source>../data/en/remove_profile.png</source>
         <translation type="unfinished">../data/en/remove_profile.png</translation>
     </message>
     <message>
-        <location filename="AddProfile.py" line="113"/>
+        <location filename="AddProfile.py" line="115"/>
         <source>../data/en/change_profile_ok.png</source>
         <translation type="unfinished">../data/en/change_profile_ok_en.png</translation>
     </message>
     <message>
-        <location filename="AddProfile.py" line="116"/>
+        <location filename="AddProfile.py" line="118"/>
         <source>../data/en/add_profile.png</source>
         <translation type="unfinished">../data/en/add_profile.png</translation>
     </message>
     <message>
-        <location filename="AddProfile.py" line="109"/>
+        <location filename="AddProfile.py" line="110"/>
         <source>Delete account</source>
         <translation type="unfinished">Удалить аккаунт</translation>
     </message>
     <message>
-        <location filename="AddProfile.py" line="114"/>
+        <location filename="AddProfile.py" line="116"/>
         <source>OK</source>
         <translation type="unfinished">OK</translation>
     </message>
     <message>
-        <location filename="AddProfile.py" line="117"/>
+        <location filename="AddProfile.py" line="119"/>
         <source>Add profile</source>
         <translation type="unfinished">Добавить аккаунт</translation>
     </message>
@@ -447,7 +447,7 @@
 <context>
     <name>ListFriendsPosts</name>
     <message>
-        <location filename="ListFriendsPosts.py" line="39"/>
+        <location filename="ListFriendsPosts.py" line="47"/>
         <source>Refresh</source>
         <translation type="unfinished">Обновить</translation>
     </message>
@@ -455,7 +455,7 @@
 <context>
     <name>ListMyPosts</name>
     <message>
-        <location filename="ListMyPosts.py" line="124"/>
+        <location filename="ListMyPosts.py" line="125"/>
         <source>Refresh</source>
         <translation type="unfinished">Обновить</translation>
     </message>
@@ -485,17 +485,17 @@
         <translation type="obsolete">Удалить</translation>
     </message>
     <message>
-        <location filename="ListMyPosts.py" line="174"/>
+        <location filename="ListMyPosts.py" line="179"/>
         <source>Scribo</source>
         <translation type="unfinished">Scribo</translation>
     </message>
     <message>
-        <location filename="ListMyPosts.py" line="154"/>
+        <location filename="ListMyPosts.py" line="159"/>
         <source>Do you really want to delete post?</source>
         <translation type="unfinished">Вы действительно хотите удалить пост?</translation>
     </message>
     <message>
-        <location filename="ListMyPosts.py" line="175"/>
+        <location filename="ListMyPosts.py" line="180"/>
         <source>Please, choose messages to delete!</source>
         <translation type="unfinished">Пожалуйста, выберите удаляемые сообщения</translation>
     </message>
@@ -505,7 +505,7 @@
         <translation type="obsolete">Подождите ...</translation>
     </message>
     <message>
-        <location filename="ListMyPosts.py" line="188"/>
+        <location filename="ListMyPosts.py" line="193"/>
         <source>Cancel</source>
         <translation type="unfinished">Отмена</translation>
     </message>
@@ -525,27 +525,27 @@
         <translation type="unfinished">Нажмите &quot;Обновить&quot; для обновления постов</translation>
     </message>
     <message>
-        <location filename="ListMyPosts.py" line="187"/>
+        <location filename="ListMyPosts.py" line="192"/>
         <source>Operation is in progress.</source>
         <translation type="unfinished">Операция выполняется</translation>
     </message>
     <message>
-        <location filename="ListMyPosts.py" line="189"/>
+        <location filename="ListMyPosts.py" line="194"/>
         <source>Receiving data...</source>
         <translation type="unfinished">Получение данных..</translation>
     </message>
     <message>
-        <location filename="ListMyPosts.py" line="125"/>
+        <location filename="ListMyPosts.py" line="124"/>
         <source>../data/en/refresh.png</source>
         <translation type="unfinished">../data/en/refresh.png</translation>
     </message>
     <message>
-        <location filename="ListMyPosts.py" line="131"/>
+        <location filename="ListMyPosts.py" line="133"/>
         <source>../data/en/post_delete.png</source>
         <translation type="unfinished">../data/en/post_delete.png</translation>
     </message>
     <message>
-        <location filename="ListMyPosts.py" line="130"/>
+        <location filename="ListMyPosts.py" line="134"/>
         <source>Delete</source>
         <translation type="unfinished">Удалить</translation>
     </message>
@@ -632,17 +632,17 @@
 <context>
     <name>MyModel</name>
     <message>
-        <location filename="TreeMessage.py" line="114"/>
+        <location filename="TreeMessage.py" line="116"/>
         <source>Author</source>
         <translation type="unfinished">Автор</translation>
     </message>
     <message>
-        <location filename="TreeMessage.py" line="115"/>
+        <location filename="TreeMessage.py" line="117"/>
         <source>Date</source>
         <translation type="unfinished">Дата</translation>
     </message>
     <message>
-        <location filename="TreeMessage.py" line="116"/>
+        <location filename="TreeMessage.py" line="118"/>
         <source>Title</source>
         <translation type="unfinished">Заголовок</translation>
     </message>
@@ -660,32 +660,32 @@
         <translation type="obsolete">Отправить</translation>
     </message>
     <message>
-        <location filename="RepeatPost.py" line="72"/>
+        <location filename="RepeatPost.py" line="74"/>
         <source>Service</source>
         <translation type="unfinished">Сервис</translation>
     </message>
     <message>
-        <location filename="RepeatPost.py" line="73"/>
+        <location filename="RepeatPost.py" line="75"/>
         <source>Login</source>
         <translation type="unfinished">Логин</translation>
     </message>
     <message>
-        <location filename="RepeatPost.py" line="185"/>
+        <location filename="RepeatPost.py" line="187"/>
         <source>Scribo</source>
         <translation type="unfinished">Scribo</translation>
     </message>
     <message>
-        <location filename="RepeatPost.py" line="149"/>
+        <location filename="RepeatPost.py" line="151"/>
         <source>Please, choose subitem for sending</source>
         <translation type="unfinished">Пожалуйста, выберите подпункт для отправки</translation>
     </message>
     <message>
-        <location filename="RepeatPost.py" line="170"/>
+        <location filename="RepeatPost.py" line="172"/>
         <source>Please, choose accounts or groups for sending</source>
         <translation type="unfinished">Пожалуйста, выберите аккаунты или группы для отправки</translation>
     </message>
     <message>
-        <location filename="RepeatPost.py" line="177"/>
+        <location filename="RepeatPost.py" line="179"/>
         <source>Post was sent</source>
         <translation type="unfinished">Пост отправлен</translation>
     </message>
@@ -705,7 +705,7 @@
         <translation type="unfinished">Отправить</translation>
     </message>
     <message>
-        <location filename="RepeatPost.py" line="187"/>
+        <location filename="RepeatPost.py" line="189"/>
         <source>Post will be lost! Continue? </source>
         <translation type="unfinished">Пост будет утерян! Продолжить?</translation>
     </message>
@@ -786,12 +786,12 @@
         <translation type="obsolete">../data/ru/home_ru.png</translation>
     </message>
     <message>
-        <location filename="ToolbarWindow.py" line="49"/>
+        <location filename="ToolbarWindow.py" line="50"/>
         <source>Back</source>
         <translation type="unfinished">Назад</translation>
     </message>
     <message>
-        <location filename="ToolbarWindow.py" line="55"/>
+        <location filename="ToolbarWindow.py" line="58"/>
         <source>Home</source>
         <translation type="unfinished">Домой</translation>
     </message>
@@ -804,12 +804,12 @@
         <translation type="obsolete">&amp;Обновить</translation>
     </message>
     <message>
-        <location filename="TreeMessage.py" line="76"/>
+        <location filename="TreeMessage.py" line="75"/>
         <source>../data/en/refresh.png</source>
         <translation type="unfinished">../data/en/refresh.png</translation>
     </message>
     <message>
-        <location filename="TreeMessage.py" line="75"/>
+        <location filename="TreeMessage.py" line="76"/>
         <source>Refresh</source>
         <translation type="unfinished">Обновить</translation>
     </message>
@@ -896,35 +896,35 @@
     <message>
         <location filename="ViewMessage.py" line="239"/>
         <source>&amp;Tree comments</source>
-        <translation type="unfinished">&amp;Дерево комментариев</translation>
+        <translation type="obsolete">&amp;Дерево комментариев</translation>
     </message>
     <message>
-        <location filename="ViewMessage.py" line="216"/>
+        <location filename="ViewMessage.py" line="217"/>
         <source>../data/en/post_prev.png</source>
         <translation type="unfinished">../data/en/post_prev.png</translation>
     </message>
     <message>
-        <location filename="ViewMessage.py" line="222"/>
+        <location filename="ViewMessage.py" line="225"/>
         <source>../data/en/post_next.png</source>
         <translation type="unfinished">../data/en/post_next.png</translation>
     </message>
     <message>
-        <location filename="ViewMessage.py" line="235"/>
+        <location filename="ViewMessage.py" line="242"/>
         <source>../data/en/post_edit.png</source>
         <translation type="unfinished">../data/en/post_edit.png</translation>
     </message>
     <message>
-        <location filename="ViewMessage.py" line="215"/>
+        <location filename="ViewMessage.py" line="218"/>
         <source>Previous</source>
         <translation type="unfinished">Пред.</translation>
     </message>
     <message>
-        <location filename="ViewMessage.py" line="221"/>
+        <location filename="ViewMessage.py" line="226"/>
         <source>Next</source>
         <translation type="unfinished">След.</translation>
     </message>
     <message>
-        <location filename="ViewMessage.py" line="234"/>
+        <location filename="ViewMessage.py" line="243"/>
         <source>Edit</source>
         <translation type="unfinished">Изменить</translation>
     </message>
@@ -932,12 +932,12 @@
 <context>
     <name>main_window</name>
     <message>
-        <location filename="ToolbarWindow.py" line="50"/>
+        <location filename="ToolbarWindow.py" line="49"/>
         <source>../data/en/back.png</source>
         <translation type="unfinished">../data/en/back.png</translation>
     </message>
     <message>
-        <location filename="ToolbarWindow.py" line="56"/>
+        <location filename="ToolbarWindow.py" line="57"/>
         <source>../data/en/home.png</source>
         <translation type="unfinished">../data/en/home.png</translation>
     </message>
