@@ -41,7 +41,7 @@ class LivejAccount(Account, Service):
     This class provide funct to access LivrJournal API
     """
 
-    def __init__(self, id=None, server_url=LJ_SERVER, userpics_url=LJ_USERPICS):
+    def __init__(self, id, server_url=LJ_SERVER, userpics_url=LJ_USERPICS):
 
         super(LivejAccount, self).__init__(id)
 
@@ -55,14 +55,19 @@ class LivejAccount(Account, Service):
         ## instance of class, to work with http requests
         self._opener = None
 
-        if not id:
-            self.service_id = type(self).__name__
-
-            self.set_option('friends_last', '0000-00-00 00:00:00')
-            self.set_option('friends', [])
-
         self._base_param = None
 
+    def reset(self):
+        """
+        Reset date in account
+        
+        @return None
+        """
+        super(LivejAccount, self).reset()
+
+        self.set_option('friends_last', '0000-00-00 00:00:00')
+        self.set_option('friends', [])
+
 
     @staticmethod
     def get_name():
@@ -237,11 +242,8 @@ class LivejAccount(Account, Service):
         journal_names = res['usejournals']
         journal_list = []
         for i in journal_names:
-            journal = self.find(LivejAccount, i)
-            if not journal:
-                journal = LivejAccount()
-                journal.username = i
-                journal.group = True
+            journal = Account.register(type(self), i)
+            journal.group = True
             journal_list.append(journal.id)
 
         self.journals_list = journal_list
@@ -545,11 +547,8 @@ class LivejAccount(Account, Service):
         parse information about LJ-user. upadate existing users and create new. 
         """
         username = self._parse_string(lj_user['username'])
-        user = self.find(LivejAccount, username)
-        if not user:
-            user = LivejAccount()
 
-        user.username = username
+        user = Account.register(type(self), username)
 
         if 'birthday' in lj_user:
             user.date_of_birth = self._parse_string(lj_user['birthday'])
@@ -651,8 +650,9 @@ class LivejAccount(Account, Service):
         poster = self.find(LivejAccount,
                            lj_post['postername'])
         if not poster:
-            poster = LivejAccount()
-            poster.username = lj_post['postername']
+            # Note: LivejAccount is base class so we have to take type(self) 
+            # as class 
+            poster = Account.register(type(self), lj_post['postername'])
             poster.group = ('P' != lj_post['postertype'])
         new_post.poster = poster
 
