@@ -7,19 +7,15 @@
   @date: 9.03.2010
 """
 
-import sys
-"""
-sys.path.append("..")
-sys.path.append("../ldm")
-sys.path.append("../ui")
-sys.path.append("../services")
-"""
+
 from ldm.Message import Message
-from ldm.Profile import *
-from ldm.Account import *
-from services.LivejAccount import *
-from time import *
-import random
+from ldm.Profile import main_prof
+from ldm.Account import Account
+from services.LivejAccount import LivejAccount
+from services.Dispatcher import dispatcher
+
+
+
 
 
 
@@ -42,43 +38,42 @@ class SysFT:
         initialization of test account
         @return
         """
-        acc = LivejAccount()
-        acc.username = "scribo_rpc"
+        service = dispatcher.get_services()[0]
+        acc = Account.register(service, "scribo_rpc")
         acc.passwd = "test123"
 
-        try:
-            main_prof.add_account(acc)
-        except:
-            print "already have"
-            acc = Account.find(type(acc), acc.username)
-        main_prof.set_def_account(acc)
+        accs = main_prof.get_accounts()
+        for acc in accs:
+            if(acc.username == "scribo_rpc"):
+                if(acc.service_id == "LivejAccount"):
+                    main_prof.set_def_account(acc)
+
 
     def get_friends_list(self):
         """
         test of getting list of friends
         """
-
-        f1 = open('./test/data/TestRes.txt', 'a')
-        f1.write('\nChecking Get Friends List Scenario with LiveJournal: ')
+        f1_ = open('./data/TestRes.txt', 'a+')
+        f1_.write('\nChecking Get Friends List Scenario with LiveJournal: ')
         print '\nChecking Get Friends List Scenario with LiveJournal: '
         try:
             main_prof.def_account.refresh_friends_list()
-            list = main_prof.def_account.get_option('friends')
+            list1 = main_prof.def_account.get_option('friends')
         except:
-            f1.write('ERROR\n')
+            f1_.write('ERROR\n')
             print "ERROR\n"
         else:
-            f1.write('OK\n')
+            f1_.write('OK\n')
             print "OK\n"
 
-        out = open('./test/data/friends.txt', 'w')
+        out = open('./data/friends.txt', 'w')
 
-        for mess in list:
+        for mess in list1:
             #print mess
             out.write('\n%s\n' % (mess))
 
         out.close()
-        f1.close()
+        f1_.close()
 
 
     def get_readers_list(self):
@@ -86,25 +81,25 @@ class SysFT:
         test of getting list of readers of our blog
         """
 
-        f1 = open('./test/data/TestRes.txt', 'a')
-        f1.write('\nChecking Get Readers List Scenario with LiveJournal: ')
+        f1_ = open('./data/TestRes.txt', 'a+')
+        f1_.write('\nChecking Get Readers List Scenario with LiveJournal: ')
         print '\nChecking Get Readers List Scenario with LiveJournal: '
         try:
             main_prof.def_account.refresh_friends_list()
-            list = main_prof.def_account.get_readers()
+            list1 = main_prof.def_account.get_readers()
         except:
-            f1.write('ERROR\n')
+            f1_.write('ERROR\n')
             print "ERROR\n"
         else:
-            f1.write('OK\n')
+            f1_.write('OK\n')
             print "OK\n"
 
-        out = open('./test/data/readers.txt', 'w')
+        out = open('./data/readers.txt', 'w')
 
-        for mess1 in list:
+        for mess1 in list1:
             #print mess1
             out.write('\n%s\n' % (mess1))
-        f1.close()
+        f1_.close()
         out.close()
 
     def add_my_friend(self):
@@ -112,23 +107,23 @@ class SysFT:
         adding a new fri(e)nd
         """
 
-        f1 = open('./test/data/TestRes.txt', 'a')
-        f1.write('\nChecking Add Friend Scenario with LiveJournal: ')
+        f1_ = open('./data/TestRes.txt', 'a+')
+        f1_.write('\nChecking Add Friend Scenario with LiveJournal: ')
         print '\nChecking Add Friend Scenario with LiveJournal: '
 
-        aco = LivejAccount()
-        aco.username = "maemoblogs"
+        service = dispatcher.get_services()[0]
+        aco = Account.register(service, "maemoblogs")
         try:
             main_prof.def_account.add_friend(aco)
         except:
-            f1.write('ERROR\n')
+            f1_.write('ERROR\n')
             print "ERROR\n"
         else:
-            f1.write('OK\n')
+            f1_.write('OK\n')
             print "OK\n"
 
         print "added\n"
-        f1.close()
+        f1_.close()
 
 
     def kill_friend(self):
@@ -136,47 +131,49 @@ class SysFT:
         testing killing a friend
         """
 
-        f1 = open('./test/data/TestRes.txt', 'a')
-        f1.write('\nChecking Delete Friend Scenario with LiveJournal: ')
+        f1_ = open('./data/TestRes.txt', 'a+')
+        f1_.write('\nChecking Delete Friend Scenario with LiveJournal: ')
         print '\nChecking Delete Friend Scenario with LiveJournal: '
-        aco = LivejAccount()
-        aco.username = "maemoblogs"
+        service = dispatcher.get_services()[0]
+        aco = Account.register(service, "maemoblogs")
         try:
             main_prof.def_account.remove_friend(aco)
         except:
-            f1.write('ERROR\n')
+            f1_.write('ERROR\n')
             print "ERROR\n"
         else:
-            f1.write('OK\n')
+            f1_.write('OK\n')
             print "OK\n"
 
-        print "killed\n"
-        f1.close()
+        f1_.close()
 
     def refreshko(self):
         """
         trying to get friends posts
         """
-        fp = []
-        f1 = open('./test/data/TestRes.txt', 'a')
-        f1.write('\nChecking get friends posts Scenario with LiveJournal: ')
+        fp_ = []
+        f1_ = open('./data/TestRes.txt', 'a+')
+        f1_.write('\nChecking get friends posts Scenario with LiveJournal: ')
         print '\nChecking get friends posts Scenario with LiveJournal: '
 
         #try:
         list_acc = main_prof.accounts
         for acc in list_acc:
+            try:
                 acc.refresh_friends_page(self.callback)
+            except:
+                print "cant get " + acc.get_service_id() + "'s friend's posts"
         try:
-            fp = main_prof.get_friends_posts(20)
+            fp_ = main_prof.get_friends_posts(20)
         except:
-            f1.write('ERROR\n')
+            f1_.write('ERROR\n')
             print "ERROR\n"
         else:
-            f1.write('OK\n')
+            f1_.write('OK\n')
             print "OK\n"
 
-        f2 = open('./test/data/friendsPostS', 'w')
-        for mess in fp:
+        f2_ = open('./data/friendsPostS', 'w')
+        for mess in fp_:
             if not mess.title:
                 title = "no subject"
             else:
@@ -184,61 +181,62 @@ class SysFT:
 
             text = mess.get_text()
 
-            f2.write('\n%s\n%s\n' % (title.encode("utf-8"), text.encode("utf-8")))
-        f1.close()
-        f2.close()
+            f2_.write('\n%s\n%s\n' % (title.encode("utf-8"),
+                                      text.encode("utf-8")))
+        f1_.close()
+        f2_.close()
 
 
-    def inboxo_O(self):
+    def inbox(self):
         """
         testing experimental inbox
         """
 
-        f1 = open('./test/data/TestRes.txt', 'a')
-        f1.write('\nChecking inbox Scenarios with LiveJournal:\n')
+        f1_ = open('./data/TestRes.txt', 'a+')
+        f1_.write('\nChecking inbox Scenarios with LiveJournal:\n')
         print '\nChecking inbox Scenarios with LiveJournal:\n'
 
         msgg = Message()
         msgg.title = unicode("hallou")
         msgg.text = unicode("tyu ")
 
-        aco = LivejAccount()
-        aco.username = "maemoblogs"
+        service = dispatcher.get_services()[0]
+        aco = Account.register(service, "maemoblogs")
         msgg.poster = aco
 
-        f1.write(' -add message to inbox ')
+        f1_.write(' -add message to inbox ')
         print ' -add message to inbox ' + "hallou " + "tyu "
         try:
             main_prof.def_account.add_inbox(msgg)
         except:
-            f1.write('ERROR\n')
+            f1_.write('ERROR\n')
             print "ERROR\n"
         else:
-            f1.write('OK\n')
+            f1_.write('OK\n')
             print "OK\n"
 
-        f1.write(' -add message to outbox ')
+        f1_.write(' -add message to outbox ')
         print ' -add message to outbox '
         try:
             main_prof.def_account.add_outbox(msgg)
         except:
-            f1.write('ERROR\n')
+            f1_.write('ERROR\n')
             print "ERROR\n"
         else:
-            f1.write('OK\n')
+            f1_.write('OK\n')
             print "OK\n"
 
-        out = open('./test/data/inbox_data.txt', 'w')
+        out = open('./data/inbox_data.txt', 'w')
 
-        f1.write(' -get message from inbox ')
+        f1_.write(' -get message from inbox ')
         print ' -get message from inbox '
         try:
             inba = main_prof.def_account.get_inbox()
         except:
-            f1.write('ERROR\n')
+            f1_.write('ERROR\n')
             print "ERROR\n"
         else:
-            f1.write('OK\n')
+            f1_.write('OK\n')
             print "OK\n"
 
 
@@ -246,15 +244,17 @@ class SysFT:
             print mess.title + '\n' + mess.text
             out.write('\n%s\n' % (mess.text))
 
-        f1.write(' -get message from outbox ')
+        f1_.write(' -get message from outbox ')
         print ' -get message from outbox '
+
+
         try:
             inba = main_prof.def_account.get_outbox()
         except:
-            f1.write('ERROR\n')
+            f1_.write('ERROR\n')
             print "ERROR\n"
         else:
-            f1.write('OK\n')
+            f1_.write('OK\n')
             print "OK\n"
         for mess in inba:
             print mess.title + '\n' + mess.text
@@ -262,7 +262,7 @@ class SysFT:
 
         out.close()
 
-        f1.close()
+        f1_.close()
 
     def callback(self):
         """
@@ -272,21 +272,20 @@ class SysFT:
 
 
 
-a = SysFT()
-"""
-testing methods, that had been described above
-stress test quoted, unquote to run
-"""
-"""
-for i in range(1, 1000):
-    a.get_friends_list()
-    a.add_my_friend()
-    a.kill_friend()
-"""
-a.get_friends_list()
-a.get_readers_list()
-a.add_my_friend()
-a.kill_friend()
-a.refreshko()
-a.inboxo_O()
+A_ = SysFT()
+
+#testing methods, that had been described above
+#stress test quoted, unquote to run
+
+#for i in range(1, 1000):
+#    a.get_friends_list()
+#    a.add_my_friend()
+#    a.kill_friend()
+
+A_.get_friends_list()
+A_.get_readers_list()
+A_.add_my_friend()
+A_.kill_friend()
+A_.refreshko()
+A_.inbox()
 print "!!!"
