@@ -101,14 +101,16 @@ class AddProfileWindow(StartPage):
         create buttons for toolbar
         @return
         """
-        self.add_acc = QtGui.QAction(self)
-        self.connect(self.add_acc, QtCore.SIGNAL("triggered()"),
+        self.add_acc = QtGui.QToolButton(self)
+        self.connect(self.add_acc, QtCore.SIGNAL("clicked()"),
                      self.add_account)
         if self.default:
-            self.del_act = QtGui.QAction(self)
+            self.del_act = QtGui.QToolButton(self)
+            self.add_acc.setIcon(QtGui.QIcon(self.tr("../data/en/remove_profile.png")))
             self.del_act.setText(self.tr("Delete account"))
-            self.del_act.setIcon(QtGui.QIcon(self.tr("../data/en/remove_profile.png")))
-            self.connect(self.del_act, QtCore.SIGNAL("triggered()"),
+            self.del_act.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
+            self.del_act.setSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
+            self.connect(self.del_act, QtCore.SIGNAL("clicked()"),
                          self.del_account_ui)
             self.add_acc.setIcon(QtGui.QIcon(self.tr("../data/en/change_profile_ok.png")))
             self.add_acc.setText(self.tr("OK"))
@@ -116,6 +118,8 @@ class AddProfileWindow(StartPage):
             self.add_acc.setIcon(QtGui.QIcon(self.tr("../data/en/add_profile.png")))
             self.add_acc.setText(self.tr("Add profile"))
 
+        self.add_acc.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
+        self.add_acc.setSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
 
 
     def create_list_acc(self, default):
