@@ -18,7 +18,15 @@ from ldm.Profile import main_prof
 from ScriboExc import WarningExc
 
 class ListFriendsPosts(ListMyPosts):
-
+    def __init__(self, parent):
+        """                                                                                                                                                 
+        initialization "list of posts" window                                                                                                               
+        @return                                                                                                                                             
+        """
+        print "begin_init"
+        super(ListFriendsPosts, self).__init__(parent)
+        print "end_init" 
+    
     def refresh_messages(self):
         list_acc = main_prof.accounts
         for acc in list_acc:
@@ -38,5 +46,5 @@ class ListFriendsPosts(ListMyPosts):
         file_tool_bar = super(ListFriendsPosts, self).create_toolbar()
         self.refresh_act.setText(self.tr("Refresh"))
         self.del_act.setDisabled(True)
-        self.del_act.deleteLater()
+        #self.del_act.deleteLater()
         return file_tool_bar
