@@ -110,8 +110,8 @@ class ListMyPosts(QtGui.QWidget):
         @return
         """
         file_tool_bar = ToolbarWindow(parent=main_window.centralWidget())
-        file_tool_bar.addAction(self.refresh_act)
-        file_tool_bar.addAction(self.del_act)
+        file_tool_bar.addWidget(self.refresh_act)
+        file_tool_bar.addWidget(self.del_act)
         return file_tool_bar
 
 
@@ -120,16 +120,21 @@ class ListMyPosts(QtGui.QWidget):
         create buttons for toolbar
         @return
         """
-        self.refresh_act = QtGui.QAction(self)
-        self.refresh_act.setText(self.tr("Refresh"))
+        self.refresh_act = QtGui.QToolButton(self)
         self.refresh_act.setIcon(QtGui.QIcon(self.tr("../data/en/refresh.png")))
-        self.connect(self.refresh_act, QtCore.SIGNAL("triggered()"),
+        self.refresh_act.setText(self.tr("Refresh"))
+        self.refresh_act.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
+        self.refresh_act.setSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
+
+        self.connect(self.refresh_act, QtCore.SIGNAL("clicked()"),
                      self.reload_window)
 
-        self.del_act = QtGui.QAction(self)
-        self.del_act.setText(self.tr("Delete"))
+        self.del_act = QtGui.QToolButton(self)
         self.del_act.setIcon(QtGui.QIcon(self.tr("../data/en/post_delete.png")))
-        self.connect(self.del_act, QtCore.SIGNAL("triggered()"),
+        self.del_act.setText(self.tr("Delete"))
+        self.del_act.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
+        self.del_act.setSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
+        self.connect(self.del_act, QtCore.SIGNAL("clicked()"),
                      self.delete_message)
 
 
