@@ -56,14 +56,16 @@ class RepeatPost(QtGui.QWidget):
         @return
         """
         file_tool_bar = ToolbarWindow(parent=main_window.centralWidget())
-        self.send_act = QtGui.QAction(self)
+        self.send_act = QtGui.QToolButton(self)
         self.send_act.setIcon(QtGui.QIcon(self.tr("../data/en/send_post.png")))
         self.send_act.setText(self.tr("Send"))
-        self.connect(self.send_act, QtCore.SIGNAL("triggered()"), self.send_selected)
-        file_tool_bar.addAction(self.send_act)
-        self.disconnect(file_tool_bar.home_act, QtCore.SIGNAL("triggered()"),
+        self.send_act.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
+        self.send_act.setSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
+        self.connect(self.send_act, QtCore.SIGNAL("clicked()"), self.send_selected)
+        file_tool_bar.addWidget(self.send_act)
+        self.disconnect(file_tool_bar.home_act, QtCore.SIGNAL("clicked()"),
                      main_window.home_window)
-        self.connect(file_tool_bar.home_act, QtCore.SIGNAL("triggered()"),
+        self.connect(file_tool_bar.home_act, QtCore.SIGNAL("clicked()"),
                      self.home_window)
         return file_tool_bar
 
