@@ -35,8 +35,8 @@ class ToolbarWindow(QtGui.QToolBar):
         else:
             self.setAllowedAreas(QtCore.Qt.LeftToolBarArea)
             self.create_actions()
-            self.addAction(self.back_act)
-            self.addAction(self.home_act)
+            self.addWidget(self.back_act)
+            self.addWidget(self.home_act)
 
 
     def create_actions(self, parent=None):
@@ -45,16 +45,20 @@ class ToolbarWindow(QtGui.QToolBar):
         @return
         """
 
-        self.back_act = QtGui.QAction(self)
-        self.back_act.setText(self.tr("Back"))
+        self.back_act = QtGui.QToolButton(self)
         self.back_act.setIcon(QtGui.QIcon(main_window.tr('../data/en/back.png')))
-        self.connect(self.back_act, QtCore.SIGNAL("triggered()"),
+        self.back_act.setText(self.tr("Back"))
+        self.back_act.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
+        self.back_act.setSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
+        self.connect(self.back_act, QtCore.SIGNAL("clicked()"),
                      main_window.back_window)
 
-        self.home_act = QtGui.QAction(self)
-        self.home_act.setText(self.tr("Home"))
+        self.home_act = QtGui.QToolButton(self)
         self.home_act.setIcon(QtGui.QIcon(main_window.tr('../data/en/home.png')))
-        self.connect(self.home_act, QtCore.SIGNAL("triggered()"),
+        self.home_act.setText(self.tr("Home"))
+        self.home_act.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
+        self.home_act.setSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
+        self.connect(self.home_act, QtCore.SIGNAL("clicked()"),
                      main_window.home_window)
 
 
