@@ -62,7 +62,7 @@ class TreeMessage(QtGui.QWidget):
         @return
         """
         file_tool_bar = ToolbarWindow(parent=main_window.centralWidget())
-        file_tool_bar.addAction(self.refresh_act)
+        file_tool_bar.addWidget(self.refresh_act)
         return file_tool_bar
 
     def create_actions(self):
@@ -71,10 +71,12 @@ class TreeMessage(QtGui.QWidget):
         @return
         """
 
-        self.refresh_act = QtGui.QAction(self)
-        self.refresh_act.setText(self.tr("Refresh"))
+        self.refresh_act = QtGui.QToolButton(self)
         self.refresh_act.setIcon(QtGui.QIcon(self.tr("../data/en/refresh.png")))
-        self.connect(self.refresh_act, QtCore.SIGNAL("triggered()"),
+        self.refresh_act.setText(self.tr("Refresh"))
+        self.refresh_act.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
+        self.refresh_act.setSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
+        self.connect(self.refresh_act, QtCore.SIGNAL("clicked()"),
                      self.reload_window)
 
     def view_message(self):
