@@ -57,8 +57,8 @@ class ViewMessage(QtGui.QWidget):
         QWebSettings.globalSettings().setAttribute(QWebSettings.JavascriptEnabled,
                                                    False)
         #cache settings
-        #QWebSettings.globalSettings().setAttribute(QWebSettings.LocalStorageEnabled,
-        #                                           True)
+        QWebSettings.globalSettings().setAttribute(QWebSettings.LocalStorageEnabled,
+                                                   True)
         #connect plugins for video
         QWebSettings.globalSettings().setAttribute(QWebSettings.PluginsEnabled,
                                                    True)
@@ -184,7 +184,7 @@ class ViewMessage(QtGui.QWidget):
         @return
         """
         file_tool_bar = ToolbarWindow(parent=main_window.centralWidget())
-        file_tool_bar.addAction(self.edit_act)
+        file_tool_bar.addWidget(self.edit_act)
         if not self.msg.is_editable():
             self.edit_act.setDisabled(True)
         return file_tool_bar
@@ -195,8 +195,8 @@ class ViewMessage(QtGui.QWidget):
         @return
         """
         second_tool_bar = ToolbarWindow(parent=main_window.centralWidget(), right=True)
-        second_tool_bar.addAction(self.up_act)
-        second_tool_bar.addAction(self.down_act)
+        second_tool_bar.addWidget(self.up_act)
+        second_tool_bar.addWidget(self.down_act)
         return second_tool_bar
 
     def create_actions(self):
@@ -205,41 +205,53 @@ class ViewMessage(QtGui.QWidget):
         @return
         """
         """
-        self.refresh_act = QtGui.QAction(self.tr("&Refresh"), self)
-        self.refresh_act.setStatusTip(self.tr("Refresh"))
+        self.refresh_act = QtGui.QToolButton(self)
+        self.refresh_act.setText(self.tr("Refresh"))
         self.refresh_act.setIcon(QtGui.QIcon("../data/refresh.png"))
-        self.connect(self.refresh_act, QtCore.SIGNAL("triggered()"),
+        self.refresh_act.setToolButtonStyle(QtCore.Qt.QToolButtonTextUnderIcon)
+        self.refresh_act.setSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)      
+        self.connect(self.refresh_act, QtCore.SIGNAL("clicked()"),
                      self.refresh_mes)
         """
-        self.up_act = QtGui.QAction(self)
-        self.up_act.setText(self.tr("Previous"))
+        self.up_act = QtGui.QToolButton(self)
         self.up_act.setIcon(QtGui.QIcon(self.tr("../data/en/post_prev.png")))
-        self.connect(self.up_act, QtCore.SIGNAL("triggered()"),
+        self.up_act.setText(self.tr("Previous"))
+        self.up_act.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
+        self.up_act.setSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)        
+        self.connect(self.up_act, QtCore.SIGNAL("clicked()"),
                      self.view_prev_message)
 
-        self.down_act = QtGui.QAction(self)
-        self.down_act.setText(self.tr("Next"))
+        self.down_act = QtGui.QToolButton(self)
         self.down_act.setIcon(QtGui.QIcon(self.tr("../data/en/post_next.png")))
-        self.connect(self.down_act, QtCore.SIGNAL("triggered()"),
+        self.down_act.setText(self.tr("Next"))
+        self.down_act.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
+        self.down_act.setSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
+        self.connect(self.down_act, QtCore.SIGNAL("clicked()"),
                      self.view_next_message)
         #don't realized
         """
-        self.comment_act = QtGui.QAction(self.tr("&Comment"), self)
-        self.comment_act.setStatusTip(self.tr("Write comment"))
+        self.comment_act = QtGui.QToolButton(self)
         self.comment_act.setIcon(QtGui.QIcon("../data/add_post.png"))
-        self.connect(self.comment_act, QtCore.SIGNAL("activated()"),
+        self.comment_act.setText(self.tr("Write comment"))
+        self.comment_act.setToolButtonStyle(QtCore.Qt.QToolButtonTextUnderIcon)
+        self.comment_act.setSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
+        self.connect(self.comment_act, QtCore.SIGNAL("clicked()"),
                      self.write_comment)
         """
-        self.edit_act = QtGui.QAction(self)
-        self.edit_act.setText(self.tr("Edit"))
+        self.edit_act = QtGui.QToolButton(self)
         self.edit_act.setIcon(QtGui.QIcon(self.tr("../data/en/post_edit.png")))
-        self.connect(self.edit_act, QtCore.SIGNAL("triggered()"),
+        self.edit_act.setText(self.tr("Edit"))
+        self.edit_act.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
+        self.edit_act.setSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
+        self.connect(self.edit_act, QtCore.SIGNAL("clicked()"),
                      self.edit_post)
 
-        self.tree_act = QtGui.QAction(self.tr("&Tree comments"), self)
-        #self.tree_act.setText(self.tr("Tree of comments"))
+        self.tree_act = QtGui.QToolButton(self)
         #self.tree_act.setIcon(QtGui.QIcon("../data/tree.png"))
-        self.connect(self.tree_act, QtCore.SIGNAL("triggered()"),
+        #self.tree_act.setText(self.tr("Tree of comments"))
+        self.tree_act.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
+        self.tree_act.setSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
+        self.connect(self.tree_act, QtCore.SIGNAL("clicked()"),
                      self.tree_comments)
 
 
